# How-To
To use one of these files with the trainer, execute the `sft_trainer.py` with the following option: 
```
--trainer_controller_config_file "examples/trainercontroller_configs/<file-name>"
```
